@@ -13,40 +13,44 @@ has [qw/param/],
     condition => sub {
         sub { defined $_[0] && length $_[0] }
     },
-    pass => sub { [] };
+    ignore => sub { [] };
 
 sub map {
     my ($self, %rule) = @_;
     my $param = $self->param;
-    $rule{$_} = {key => $_} for @{$self->pass};
+    my %ignore = map { $_ => 1 } @{$self->ignore};
     
     # Mapping
     my $new_param = {};
-    for my $key (keys %rule) {
+    foreach my $key (keys %$param) {
         
-        my $mapping = $rule{$key};
+        next if $ignore{$key};
+        
+        my $value_cb;
+        my $condition;
+        my $new_key;
         
         # Get mapping information
-        my $new_key;
-        my $value;
-        my $condition;
-        
-        if (ref $mapping eq 'ARRAY') {
-            $new_key = $mapping->[0];
-            $value = $mapping->[1];
-            $condition = ref $mapping->[2] eq 'HASH' ? $mapping->[2]->{condition} : $mapping->[2];
+        if (ref $rule{$key} eq 'ARRAY') {
+            foreach my $some (@{$rule{$key}}) {
+                $new_key = $some unless ref $some;
+                $condition = $some->{condition} if ref $some eq 'HASH';
+                $value_cb = $some if ref $some eq 'CODE';
+            }
         }
-        elsif (ref $mapping eq 'HASH') {
-            $new_key = $mapping->{key};
-            $value = $mapping->{value};
-            $condition = $mapping->{condition};
+        elsif (defined $rule{$key}) {
+            $new_key = $rule{$key};
+        }
+        else {
+            $new_key = $key;
         }
         
-        $new_key = $key unless defined $new_key;
+        $value_cb ||= sub { $_[0] };
         $condition ||= $self->condition;
         $condition = $self->_condition_to_sub($condition);
 
         # Map parameter
+        my $value;
         if (ref $condition eq 'CODE') {
             if (ref $param->{$key} eq 'ARRAY') {
                 $new_param->{$new_key} = [];
@@ -57,11 +61,8 @@ sub map {
                 }
             }
             else {
-              if ($condition->($param->{$key})) {
-                  $new_param->{$new_key} = defined $value
-                                         ? $value->($param->{$key})
-                                         : $param->{$key};
-              }
+                $new_param->{$new_key} = $value_cb->($param->{$key})
+                  if $condition->($param->{$key});
             }
         }
         elsif ($condition eq 'exists') {
@@ -74,11 +75,8 @@ sub map {
                 }
             }
             else {
-                if (exists $param->{$key}) {
-                    $new_param->{$new_key} = defined $value
-                                           ? $value->($param->{$key})
-                                           : $param->{$key};
-                }
+                $new_param->{$new_key} = $value_cb->($param->{$key})
+                  if exists $param->{$key};
             }
         }
         else { croak qq/Condition must be code reference or "exists" / . _subname }
@@ -92,7 +90,7 @@ sub new {
     
     # Check attribute names
     my @attrs = keys %$self;
-    for my $attr (@attrs) {
+    foreach my $attr (@attrs) {
         croak qq{"$attr" is invalid attribute name (} . _subname . ")"
           unless $self->can($attr);
     }
@@ -119,7 +117,7 @@ sub _condition_to_sub {
 
 =head1 NAME
 
-DBIx::Custom::Mapper - Mapper of parameter
+DBIx::Custom::Mapper - Mapper of parameter EXPERIMENTAL
 
 =head1 SYNOPSYS
 
@@ -139,12 +137,12 @@ DBIx::Custom::Mapper - Mapper of parameter
 
 Parameter.
 
-=head2 C<pass>
+=head2 C<ignore>
 
-    my $pass = $mapper->pass;
-    $mapper = $mapper->pass([qw/title author/]);
+    my $pass = $mapper->ignore;
+    $mapper = $mapper->ignore([qw/title author/]);
 
-the key and value is copied without change when C<map> method is executed.
+Ignored parameter keys when C<map> method is executed.
 
 =head2 C<condition>
 
@@ -190,12 +188,12 @@ and implements the following new ones.
 =head2 C<map>
 
     my $new_param = $mapper->map(
-        price => {key => 'book.price'}
-        title => {value => sub { '%' . $_[0] . '%'}}
-        author => ['book.author' => sub { '%' . $_[0] . '%'}] # Key and value
+        price => 'book.price', # Key
+        title => sub { '%' . $_[0] . '%'}, # Value
+        author => ['book.author', sub { '%' . $_[0] . '%'}] # Key and value
     );
 
-Map C<param> into new parameter.
+Map C<param>'s key and value and return new parameter.
 
 For example, if C<param> is set to
 
@@ -212,6 +210,7 @@ The following hash reference is returned.
         'book.price' => 1900,
         title => '%Perl%',
         'book.author' => '%Ken%',
+        issude_date => '2010-11-11'
     }
 
 By default, If the value has length, key and value is mapped.
@@ -228,22 +227,16 @@ You can set change mapping condition by C<condition> attribute.
 Or you can set C<condtion> option for each key.
 
     my $new_param = $mapper->map(
-        price => {key => 'book.price', condition => 'defined'}]
-        title => {value => sub { '%' . $_[0] . '%'}, condition => 'defined'}
-        author => ['book.author', sub { '%' . $_[0] . '%'}, 'exists']
+        price => ['book.price', {condition => 'defined'}]
+        title => [sub { '%' . $_[0] . '%'}, {condition => 'defined'}] # Value
+        author => ['book.author', sub { '%' . $_[0] . '%'}, condtion => 'exists']
     );
 
-If C<pass> attrivute is set, the keys and value is copied without change.
+If C<ignore> is set, the keys is ignored.
 
-    $mapper->pass([qw/title author/]);
-    my $new_param = $mapper->map(price => {key => 'book.price'});
-
-The following hash reference
+    $mapper->ignore([qw/title author/]);
     
     {title => 'Perl', author => 'Ken', price => 1900}
-
-is mapped to
-
-    {title => 'Perl', author => 'Ken', 'book.price' => 1900}
+      is mapped to {price => 1900}
 
 =cut
